MatrixBlock constructor

MatrixBlock(
  1. Float64List storage,
  2. int offset,
  3. int stride,
  4. int rows,
  5. int cols,
)

A view of rows x cols starting at offset, where consecutive rows of the view are stride elements apart in storage.

Implementation

MatrixBlock(this.storage, this.offset, this.stride, this.rows, this.cols);